#include "Game.hpp"

CGame::CGame()
{
	m_pPlayer = NULL;
	m_pSpriteBackground = NULL;
	m_pSpriteAsteroid = NULL;
}

void CGame::Init()
{
	m_pPlayer = new CPlayer;
	m_pPlayer->Init();
	m_pPlayer->Reset();

	m_pSpriteBackground = new CSprite;
	m_pSpriteBackground->Load("Data/Background.bmp", 20, 64, 64);

	m_pSpriteAsteroid = new CSprite;
	m_pSpriteAsteroid->Load("Data/Asteroid.bmp", 20, 64, 64);
	m_pSpriteAsteroid->SetColorKey(255, 0, 255);

	m_fAsteroidTimer = 0.0f;
	m_bGameRun = true;
}

void CGame::Quit()
{
	if(m_pPlayer != NULL)
	{
		m_pPlayer->Quit();
		delete m_pPlayer;
		m_pPlayer = NULL;
	}

	SAFE_DELETE(m_pSpriteBackground);
	SAFE_DELETE(m_pSpriteAsteroid);
}

void CGame::Run()
{
	while(m_bGameRun == true)
	{
		ProcessEvents();

		g_pFramework->Update();
		g_pFramework->Clear();

		m_pSpriteBackground->Render();

		m_pPlayer->Update();
		m_pPlayer->Render();

		SpawnAsteroids();
		CheckCollisions();

		RenderAsteroids();
		g_pFramework->Flip();
	}
}

void CGame::ProcessEvents()
{
	SDL_Event Event;
	
	if(SDL_PollEvent(&Event))
	{
		switch(Event.type)
		{
			case (SDL_QUIT):
			{
				m_bGameRun = false;
				break;
			}

			case (SDL_KEYDOWN):
			{
				switch(Event.key.keysym.sym)
				{
					case (SDLK_ESCAPE):
					{
						m_bGameRun = false;
						break;
					}
				}

				break;
			}
		}
	}
}

void CGame::SpawnAsteroids()
{
	m_fAsteroidTimer += g_pTimer->GetElapsed();

	if(m_fAsteroidTimer >= 0.5f)
	{
		CAsteroid Asteroid;
		int XPos = rand() % 736;

		Asteroid.Init(m_pSpriteAsteroid, static_cast<float>(XPos), -60.0f);

		m_AsteroidList.push_back(Asteroid);
		m_fAsteroidTimer = 0.0f;
	}
}

void CGame::CheckCollisions()
{
	list<CShot> *ShotList = m_pPlayer->GetShotList();

	list<CAsteroid>::iterator ItAsteroid = m_AsteroidList.begin();
	list<CShot>::iterator ItShot;

	SDL_Rect RectAsteroid;
	SDL_Rect RectShot;

	while(ItAsteroid != m_AsteroidList.end())
	{
		RectAsteroid = ItAsteroid->GetRect();

		for(ItShot = ShotList->begin(); ItShot != ShotList->end(); ++ItShot)
		{
			RectShot = ItShot->GetRect();

			if(RectShot.y < RectAsteroid.y + RectAsteroid.h && RectShot.y + RectShot.h > RectAsteroid.y &&
			   RectShot.x < RectAsteroid.x + RectAsteroid.w && RectShot.x + RectShot.w > RectAsteroid.x)
			{
				ItAsteroid->SetAlive(false);
				ItShot->SetAlive(false);
			}
		}

		if(ItAsteroid->IsAlive())
			ItAsteroid++;
		else
			ItAsteroid = m_AsteroidList.erase(ItAsteroid);
	}
}

void CGame::RenderAsteroids()
{
	list<CAsteroid>::iterator It;

	for(It = m_AsteroidList.begin(); It != m_AsteroidList.end(); ++It)
	{
		It->Render();
		It->Update();
	}
}