#include "Player.hpp"

CPlayer::CPlayer()
{
	m_pSpritePlayer = NULL;
	m_pSpriteShot = NULL;
}

void CPlayer::Init()
{
	m_pSpritePlayer = new CSprite;

	m_pSpritePlayer->Load("Data/Player.bmp", 11, 64, 64);
	m_pSpritePlayer->SetColorKey(255, 0, 255);

	m_pSpriteShot = new CSprite;

	m_pSpriteShot->Load("Data/Laser.bmp", 0, 64, 64);
	m_pSpriteShot->SetColorKey(255, 0, 255);
}

void CPlayer::Quit()
{
	SAFE_DELETE(m_pSpritePlayer);
	SAFE_DELETE(m_pSpriteShot);
}

void CPlayer::Reset()
{
	m_fXPos = 376.0f;
	m_fYPos = 520.0f;

	m_fAnimPhase = 5.0f;
	m_bShotLock = false;
}

void CPlayer::Render()
{
	m_pSpritePlayer->SetPos(m_fXPos, m_fYPos);
	m_pSpritePlayer->Render(m_fAnimPhase);

	list<CShot>::iterator it = m_ShotList.begin();

	while(it != m_ShotList.end())
	{
		it->Update();

		if(it->IsAlive())
		{
			it->Render();
			it++;
		}
		else
		{
			it = m_ShotList.erase(it);
		}
	}
}

void CPlayer::Update()
{
	ProcessMoving();
	ProcessShooting();
	CheckPosition();
}

void CPlayer::ProcessMoving()
{
	if(g_pFramework->KeyDown(SDLK_LEFT))
	{
		m_fXPos -= 300.0f * g_pTimer->GetElapsed();
		m_fAnimPhase -= 20.0f * g_pTimer->GetElapsed();
	}
	else if(g_pFramework->KeyDown(SDLK_RIGHT))
	{
		m_fXPos += 300.0f * g_pTimer->GetElapsed();
		m_fAnimPhase += 20.0f * g_pTimer->GetElapsed();
	}
	else
	{
		if(m_fAnimPhase > 5.0f)
			m_fAnimPhase -= 20.0f * g_pTimer->GetElapsed();
		
		if(m_fAnimPhase < 5.0f)
			m_fAnimPhase += 20.0f * g_pTimer->GetElapsed();
	}
}

void CPlayer::ProcessShooting()
{
	if(g_pFramework->KeyDown(SDLK_SPACE) && m_bShotLock == false)
	{
		CShot shot;
		shot.Init(m_pSpriteShot, m_fXPos, m_fYPos);

		m_ShotList.push_back(shot);
		m_bShotLock = true;
	}

	if(g_pFramework->KeyDown(SDLK_SPACE) == false)
		m_bShotLock = false;
}

void CPlayer::CheckPosition()
{
	if(m_fXPos < 0.0f)
		m_fXPos = 0.0f;
	else if(m_fXPos > 752.0f)
		m_fXPos = 752.0f;

	if(m_fAnimPhase < 0.0f)
		m_fAnimPhase = 0.0f;
	else if(m_fAnimPhase > 10.0f)
		m_fAnimPhase = 10.0f;
}